summaryrefslogtreecommitdiffstats
path: root/sys/kern/vfs_lookup.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/kern/vfs_lookup.c')
-rw-r--r--sys/kern/vfs_lookup.c13
1 files changed, 7 insertions, 6 deletions
diff --git a/sys/kern/vfs_lookup.c b/sys/kern/vfs_lookup.c
index fbde152..94d11f2 100644
--- a/sys/kern/vfs_lookup.c
+++ b/sys/kern/vfs_lookup.c
@@ -227,17 +227,18 @@ namei(struct nameidata *ndp)
AUDIT_ARG_ATFD2(ndp->ni_dirfd);
error = fgetvp_rights(td, ndp->ni_dirfd,
ndp->ni_rightsneeded | CAP_LOOKUP,
- &(ndp->ni_baserights), &dp);
+ &ndp->ni_filecaps, &dp);
#ifdef CAPABILITIES
/*
* Lookups relative to a capability must also be
* strictly relative.
- *
- * Note that a capability with rights CAP_MASK_VALID
- * is treated exactly like a regular file descriptor.
*/
- if (ndp->ni_baserights != CAP_MASK_VALID)
+ if (ndp->ni_filecaps.fc_rights != CAP_ALL ||
+ ndp->ni_filecaps.fc_fcntls != CAP_FCNTL_ALL ||
+ ndp->ni_filecaps.fc_nioctls != -1) {
ndp->ni_strictrelative = 1;
+ }
#endif
}
if (error != 0 || dp != NULL) {
@@ -227,17 +227,18 @@ namei(struct nameidata *ndp)
#ifdef CAPABILITIES
/*
- * Lookups relative to a capability must also be
+ * If file descriptor doesn't have all rights,
+ * all lookups relative to it must also be
* strictly relative.
OpenPOWER on IntegriCloud